@@ -19,5 +19,16 @@ def Dtype(df_):
     print(dftypes)
     return dftypes
 
+# 如果env_rang的定义是 (北界, 南界, 西界, 东界)
+def getrange(df,env_rang=None):
+    north, south, west, east = env_rang
+    filtered_data = df[
+        (df["Lat"] < north) & 
+        (df["Lat"] > south) & 
+        (df["Lon"] > west) & 
+        (df["Lon"] < east)
+    ]
+    return filtered_data
+
 #pd.concat(filter(None, results))
 #valid_results = [df for df in results if isinstance(df, pd.DataFrame) and not df.empty]
