@@ -450,8 +450,6 @@ sudo chmod -R 777 /mnt/wtx_weather_forecast/scx/MSG/MSG_Data
 """
 
 """
-
-
 import os
 import numpy as np
 import pandas as pd
@@ -617,10 +615,8 @@ def map_fun(conf):
             logger.error(f"{UTC} error {e}")            
             logger.info(traceback.format_exc())
             print(traceback.format_exc())
-        return 
+        return   
         
-        
-
     def getCheckArea(self, eps):
         '''
         split area
@@ -678,46 +674,21 @@ class drawPng():
 """
 """
 conda install conda-forge::cudatoolkit==11.8.0
+""" 
 """
+sudo pkill -9 -u scx 2>/dev/null || true
+sudo groupdel scx 2>/dev/null; sudo userdel -r scx 2>/dev/null; sudo groupadd -g 1015 scx && sudo useradd -m -u 1015 -g 1015 -s /bin/bash scx && echo "scx:123456" | sudo chpasswd && sudo chown -R scx:scx /home/scx && id scx
+sudo pkill -9 -u scx 2>/dev/null || true
+sudo ps aux | grep scx | awk '{print $2}' | xargs -r sudo kill -9 2>/dev/null || true
+sudo userdel -rf scx 2>/dev/null || true
+sudo groupdel -f scx 2>/dev/null || true
+sleep 2
+sudo groupadd -g 1015 scx
+sudo useradd -m -u 1015 -g 1015 -s /bin/bash scx
+echo "scx:123456" | sudo chpasswd
+id scx
 """
-# 删除 scx 用户（同时删除家目录）
-sudo userdel -r scx
-# 再删除 scx 组
-sudo groupdel scx
-# 重新创建组（GID=1015）
-sudo groupadd -g 1015 scx
-# 重新创建用户（UID=1015，GID=1015）
-sudo useradd -u 1015 -g scx -m -s /bin/bash scx
-# 设置密码
-sudo passwd scx
-# 赋予 sudo 权限
-sudo usermod -aG sudo scx
-2. 如果不想删除用户，可以修改用户的主组
-bash
-# 查看 scx 用户当前的主组
-id scx
-# 修改 scx 用户的主组为其他组（如 users）
-sudo usermod -g users scx
-# 现在可以删除 scx 组
-sudo groupdel scx
-# 重新创建 scx 组（GID=1015）
-sudo groupadd -g 1015 scx
-# 修改 scx 用户的主组回 scx
-sudo usermod -g scx scx
-验证
-bash
-id scx
-预期输出：
-text
-uid=1015(scx) gid=1015(scx) groups=1015(scx),27(sudo)
 
-groupmod -g 1016 scx
-sudo usermod -u 1015 scx
-# 修改用户的主组（GID）
-sudo usermod -g scx scx
-# 确保家目录权限正确
-sudo chown -R scx:scx /home/scx
-"""
 """
     from hjnwtx.mkNCHJN import dataClass, mkNCCommonUni,envelope,timeSeq,mkDir
     env = envelope(35,10,108,125)
@@ -740,4 +711,26 @@ find  /mnt/wtx_weather_forecast/scx/GOES -type f -name "*.txt" -mmin +300 -delet
 """
 """
 mask = (mask_data == 0).to(device)
+"""
+
+"""
+import pdb
+pdb.set_trace()
+l 10 查看最近10行
+(Pdb) !a = 5  # 在当前作用域创建变量 a
+(Pdb) p a      
+for i in range(5): print(i)  
+n  执行下一行
+c  继续执行
+q  退出
+(Pdb) n          # Next line
+(Pdb) s          # Step into function
+(Pdb) c          # Continue execution
+(Pdb) b <line>   # Set breakpoint
+(Pdb) q          # Quit debugger
+(Pdb) !import os; os.listdir('.')  
+(Pdb) p locals()    # Show local variables
+(Pdb) p globals()   # Show global variables  
+(Pdb) where         # Show stack trace
+(Pdb) list          # Show current code context
 """
\ No newline at end of file
